@@ -66,7 +66,7 @@ drive_change_publish <- function(file,
     ))
   }
 
-  params <- toCamel(list(...))
+  params <- toCamel(rlang::list2(...))
   params[["published"]] <- publish
   params[["publishAuto"]] <- params[["publishAuto"]] %||% TRUE
   params[["publishedOutsideDomain"]] <-
@@ -91,12 +91,12 @@ drive_change_publish <- function(file,
 
 change_publish_one <- function(id, params) {
   params[["fileId"]] <- id
-  request <- generate_request(
+  request <- request_generate(
     endpoint = "drive.revisions.update",
     params = params
   )
-  response <- make_request(request, encode = "json")
-  process_response(response)
+  response <- request_make(request, encode = "json")
+  gargle::response_process(response)
 }
 
 drive_reveal_published <- function(file) {
@@ -116,7 +116,7 @@ drive_reveal_published <- function(file) {
 }
 
 get_publish_one <- function(id) {
-  request <- generate_request(
+  request <- request_generate(
     endpoint = "drive.revisions.get",
     params = list(
       fileId = id,
@@ -124,10 +124,10 @@ get_publish_one <- function(id) {
       fields = "*"
     )
   )
-  response <- make_request(request)
+  response <- request_make(request)
   ## folders generate a 403
   if (httr::status_code(response) == 403) {
     return(NULL)
   }
-  process_response(response)
+  gargle::response_process(response)
 }
