@@ -73,7 +73,7 @@ drive_share <- function(file,
   file <- as_dribble(file)
   file <- confirm_some_files(file)
 
-  params <- toCamel(list(...))
+  params <- toCamel(rlang::list2(...))
   params[["role"]] <- role
   params[["type"]] <- type
   params[["fields"]] <- "*"
@@ -110,12 +110,12 @@ drive_share <- function(file,
 
 drive_share_one <- function(id, params, verbose) {
   params[["fileId"]] <- id
-  request <- generate_request(
+  request <- request_generate(
     endpoint = "drive.permissions.create",
     params = params
   )
-  response <- make_request(request, encode = "json")
-  process_response(response)
+  response <- request_make(request, encode = "json")
+  gargle::response_process(response)
 }
 
 drive_reveal_permissions <- function(file) {
@@ -137,7 +137,7 @@ drive_reveal_permissions <- function(file) {
 }
 
 list_permissions_one <- function(id) {
-  request <- generate_request(
+  request <- request_generate(
     endpoint = "drive.permissions.list",
     params = list(
       fileId = id,
@@ -146,11 +146,11 @@ list_permissions_one <- function(id) {
   )
   ## TO DO: we aren't dealing with the fact that this endpoint is paginated
   ## for Team Drives
-  response <- make_request(request, encode = "json")
+  response <- request_make(request, encode = "json")
   ## if capabilities/canReadRevisions (present in File resource) is not true,
   ## user will get a 403 "insufficientFilePermissions" here
   if (httr::status_code(response) == 403) {
     return(NULL)
   }
-  process_response(response)
+  gargle::response_process(response)
 }
